==> jc-1.4.0.tar.gz: javax/swing/AbstractSpinnerModel.h <==
// public abstract class javax.swing.AbstractSpinnerModel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4b0089f574438731 javax_swing_AbstractSpinnerModel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_AbstractSpinnerModel_H_
#define _JC_javax_swing_AbstractSpinnerModel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_event_ChangeListener$object;
struct _jc_javax_swing_event_EventListenerList$object;

// Typedefs
typedef struct _jc_javax_swing_AbstractSpinnerModel$sub_refs	_jc_javax_swing_AbstractSpinnerModel$sub_refs;
typedef struct _jc_javax_swing_AbstractSpinnerModel$sub_nonrefs	_jc_javax_swing_AbstractSpinnerModel$sub_nonrefs;
typedef struct _jc_javax_swing_AbstractSpinnerModel$refs	_jc_javax_swing_AbstractSpinnerModel$refs;
typedef struct _jc_javax_swing_AbstractSpinnerModel$nonrefs	_jc_javax_swing_AbstractSpinnerModel$nonrefs;
typedef struct _jc_javax_swing_AbstractSpinnerModel$object	_jc_javax_swing_AbstractSpinnerModel$object;

typedef struct _jc_javax_swing_AbstractSpinnerModel$fields_struct	_jc_javax_swing_AbstractSpinnerModel$fields_struct;
typedef const struct _jc_javax_swing_AbstractSpinnerModel$vmethods	_jc_javax_swing_AbstractSpinnerModel$vmethods;
typedef const struct _jc_javax_swing_AbstractSpinnerModel$vtable	_jc_javax_swing_AbstractSpinnerModel$vtable;
typedef const struct _jc_javax_swing_AbstractSpinnerModel$vtype	_jc_javax_swing_AbstractSpinnerModel$vtype;

// Class fields structure
struct _jc_javax_swing_AbstractSpinnerModel$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24event__24ChangeListener;
};
extern _jc_javax_swing_AbstractSpinnerModel$fields_struct _jc_javax_swing_AbstractSpinnerModel$class_fields;

// Constructors
extern void _jc_javax_swing_AbstractSpinnerModel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *);

// Virtual methods
extern void _jc_javax_swing_AbstractSpinnerModel$method$addChangeListener$1fcb1bdc58c7c6d8(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_object *);
extern void _jc_javax_swing_AbstractSpinnerModel$method$fireStateChanged$6a2faae97d997d9a(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *);
extern _jc_object_array *_jc_javax_swing_AbstractSpinnerModel$method$getChangeListeners$9dde76dbf9f557be(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *);
extern _jc_object_array *_jc_javax_swing_AbstractSpinnerModel$method$getListeners$672bd3c8700d71ef(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_java_lang_Class$object *);
extern void _jc_javax_swing_AbstractSpinnerModel$method$removeChangeListener$91e6a7f8d24a5df2(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_object *);
extern void _jc_javax_swing_AbstractSpinnerModel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$addChangeListener$1fcb1bdc58c7c6d8;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$fireStateChanged$6a2faae97d997d9a;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$getChangeListeners$9dde76dbf9f557be;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$getListeners$672bd3c8700d71ef;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$removeChangeListener$91e6a7f8d24a5df2;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_swing_AbstractSpinnerModel$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_swing_AbstractSpinnerModel$vmethods {
	void	(*addChangeListener$1fcb1bdc58c7c6d8)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_object *);
	void	(*fireStateChanged$6a2faae97d997d9a)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *);
	_jc_object_array	*(*getChangeListeners$9dde76dbf9f557be)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *);
	_jc_object_array	*(*getListeners$672bd3c8700d71ef)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_java_lang_Class$object *);
	void	(*removeChangeListener$91e6a7f8d24a5df2)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *);
};

// Vtable
struct _jc_javax_swing_AbstractSpinnerModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractSpinnerModel$vmethods	javax_swing_AbstractSpinnerModel;
};

// Vtype
struct _jc_javax_swing_AbstractSpinnerModel$vtype {
	_jc_type			type;
	_jc_javax_swing_AbstractSpinnerModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_AbstractSpinnerModel$sub_refs {
	struct _jc_javax_swing_event_ChangeEvent$object	*changeEvent;
	struct _jc_javax_swing_event_EventListenerList$object	*listenerList;
};

// Reference instance fields (object)
struct _jc_javax_swing_AbstractSpinnerModel$refs {
    _jc_javax_swing_AbstractSpinnerModel$sub_refs	javax_swing_AbstractSpinnerModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_AbstractSpinnerModel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_AbstractSpinnerModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractSpinnerModel$sub_nonrefs	javax_swing_AbstractSpinnerModel;
};

// Object instance structure
struct _jc_javax_swing_AbstractSpinnerModel$object {
	_jc_javax_swing_AbstractSpinnerModel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_AbstractSpinnerModel$vtype	*vtype;
	_jc_javax_swing_AbstractSpinnerModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_AbstractSpinnerModel$vtype _jc_javax_swing_AbstractSpinnerModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_AbstractSpinnerModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_AbstractSpinnerModel$class_object;

#endif	/* _JC_javax_swing_AbstractSpinnerModel_H_ */

==> jc-1.4.6.tar.gz: javax/swing/AbstractSpinnerModel.h <==
// public abstract class javax.swing.AbstractSpinnerModel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4b0089f574438731 javax_swing_AbstractSpinnerModel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_AbstractSpinnerModel_H_
#define _JC_javax_swing_AbstractSpinnerModel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_event_ChangeListener$object;
struct _jc_javax_swing_event_EventListenerList$object;

// Typedefs
typedef struct _jc_javax_swing_AbstractSpinnerModel$sub_refs	_jc_javax_swing_AbstractSpinnerModel$sub_refs;
typedef struct _jc_javax_swing_AbstractSpinnerModel$sub_nonrefs	_jc_javax_swing_AbstractSpinnerModel$sub_nonrefs;
typedef struct _jc_javax_swing_AbstractSpinnerModel$refs	_jc_javax_swing_AbstractSpinnerModel$refs;
typedef struct _jc_javax_swing_AbstractSpinnerModel$nonrefs	_jc_javax_swing_AbstractSpinnerModel$nonrefs;
typedef struct _jc_javax_swing_AbstractSpinnerModel$object	_jc_javax_swing_AbstractSpinnerModel$object;

typedef struct _jc_javax_swing_AbstractSpinnerModel$fields_struct	_jc_javax_swing_AbstractSpinnerModel$fields_struct;
typedef const struct _jc_javax_swing_AbstractSpinnerModel$vmethods	_jc_javax_swing_AbstractSpinnerModel$vmethods;
typedef const struct _jc_javax_swing_AbstractSpinnerModel$vtable	_jc_javax_swing_AbstractSpinnerModel$vtable;
typedef const struct _jc_javax_swing_AbstractSpinnerModel$vtype	_jc_javax_swing_AbstractSpinnerModel$vtype;

// Class fields structure
struct _jc_javax_swing_AbstractSpinnerModel$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24event__24ChangeListener;
};
extern _jc_javax_swing_AbstractSpinnerModel$fields_struct _jc_javax_swing_AbstractSpinnerModel$class_fields;

// Constructors
extern void _jc_javax_swing_AbstractSpinnerModel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_AbstractSpinnerModel$method$addChangeListener$1fcb1bdc58c7c6d8(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_AbstractSpinnerModel$method$fireStateChanged$6a2faae97d997d9a(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_AbstractSpinnerModel$method$getChangeListeners$9dde76dbf9f557be(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_AbstractSpinnerModel$method$getListeners$672bd3c8700d71ef(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_AbstractSpinnerModel$method$removeChangeListener$91e6a7f8d24a5df2(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_AbstractSpinnerModel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$addChangeListener$1fcb1bdc58c7c6d8;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$fireStateChanged$6a2faae97d997d9a;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$getChangeListeners$9dde76dbf9f557be;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$getListeners$672bd3c8700d71ef;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$removeChangeListener$91e6a7f8d24a5df2;
extern _jc_method _jc_javax_swing_AbstractSpinnerModel$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_swing_AbstractSpinnerModel$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_AbstractSpinnerModel$vmethods {
	void	(*addChangeListener$1fcb1bdc58c7c6d8)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*fireStateChanged$6a2faae97d997d9a)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getChangeListeners$9dde76dbf9f557be)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getListeners$672bd3c8700d71ef)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	void	(*removeChangeListener$91e6a7f8d24a5df2)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_AbstractSpinnerModel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_AbstractSpinnerModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractSpinnerModel$vmethods	javax_swing_AbstractSpinnerModel;
};

// Vtype
struct _jc_javax_swing_AbstractSpinnerModel$vtype {
	_jc_type			type;
	_jc_javax_swing_AbstractSpinnerModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_AbstractSpinnerModel$sub_refs {
	struct _jc_javax_swing_event_ChangeEvent$object	*changeEvent;
	struct _jc_javax_swing_event_EventListenerList$object	*listenerList;
};

// Reference instance fields (object)
struct _jc_javax_swing_AbstractSpinnerModel$refs {
    _jc_javax_swing_AbstractSpinnerModel$sub_refs	javax_swing_AbstractSpinnerModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_AbstractSpinnerModel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_AbstractSpinnerModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractSpinnerModel$sub_nonrefs	javax_swing_AbstractSpinnerModel;
};

// Object instance structure
struct _jc_javax_swing_AbstractSpinnerModel$object {
	_jc_javax_swing_AbstractSpinnerModel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_AbstractSpinnerModel$vtype	*vtype;
	_jc_javax_swing_AbstractSpinnerModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_AbstractSpinnerModel$vtype _jc_javax_swing_AbstractSpinnerModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_AbstractSpinnerModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_AbstractSpinnerModel$class_object;

#endif	/* _JC_javax_swing_AbstractSpinnerModel_H_ */
